@@ -227,22 +227,26 @@ class Postgres_Handler:
         table_name = kwargs[self.table_name_key]
         
         #Begining of the SQL query
-        query_start = 'UPDATE %(table_name)s SET'
+        query_string= "UPDATE {table_name} SET "
+        
         values_dict[self.table_name_key] = table_name
         
         for key, value in kwargs.items():
-            if key.lower() == "id": continue
+            if key.lower() == "id" or key.lower() == table_name: continue
             
-            clause_section = f' "{key}" = %({key})s,'
+            clause_section = f' "{key}" = %({key})s AND '
             values_dict[key] = value
         
         query_string += clause_section[:-1]
-        
+
         if id_key not in kwargs: assert("Error: ID of record required for an update!")
-        id_val = kwargs['id']
-        query_string += f' WHERE "ID"=\'{id_val}\''
         
-        results = self.__run_query(query_string)
+        query_string += f' WHERE "ID"=(id)s'
+        values_dict['id'] = kwargs['id']
+        
+        sql_query = sql.SQL(query_string).format(sql.Identifier(table_name = kwargs[self.table_name_key]))
+        
+        results = self.__run_query(sql_query)
         return self.__format_results(results)
     
         
@@ -257,8 +261,12 @@ class Postgres_Handler:
         value_dict = {key: value for key, value in kwargs.items() if key.lower() == table_name_key.lower() or key.lower() == id_key.lower()}
         
         #Builds query to run 
-        query_string = 'DELETE FROM %(table_name)s WHERE ID = %(ID)s'
+        query_string = 'DELETE FROM {table_name} WHERE ID = {Id}'
+        sql_query = sql.SQL(query_string).format(
+            table_name = sql.Identifier(kwargs[table_name_key]),
+            Id= sql.Identifier(kwargs[id_key])
+        )
         
         #Runs the query and handles the success or error.
-        results = self.__run_query(query_string, value_dict)
+        results = self.__run_query(sql_query, value_dict)
         return results
